import json

import pandas as pd

from notedata.manage.core import download
from notetool.tool import decompress
from notetool.tool.path import rename, path_parse

pd.set_option('display.max_columns', None)
pd.set_option('display.max_rows', 200)
pd.set_option('max_colwidth', 500)


def dataset_coco(data_root='./download/coco/'):
    def step1():
        download('coco-annotations_trainval2017', path=data_root)
        download('coco-val2017', path=data_root)

        decompress(data_root + "annotations_trainval2017.zip", target_dir=data_root)
        decompress(data_root + "val2017.zip", target_dir=data_root)

        rename(data_root + 'val2017', data_root + 'images')

    def step2(json_path, target_file):
        json_data = json.load(open(json_path))
        df_annotations = pd.DataFrame.from_dict(json_data['annotations'])

        df_categories = pd.DataFrame.from_dict(json_data['categories'])
        df_categories.reset_index(inplace=True)

        df_annotations = pd.merge(df_annotations, df_categories[['id', 'index']],
                                  left_on='category_id', right_on='id', suffixes=('', '_y')).drop(['id_y'], axis=1)

        df_annotations['xmin'] = df_annotations['bbox'].apply(lambda x: int(x[0]))
        df_annotations['ymin'] = df_annotations['bbox'].apply(lambda x: int(x[1]))
        df_annotations['xmax'] = df_annotations['bbox'].apply(lambda x: int(x[2] + x[0]))
        df_annotations['ymax'] = df_annotations['bbox'].apply(lambda x: int(x[3] + x[1]))

        df_annotations['label'] = df_annotations['bbox'].apply(
            lambda x: '{},{},{},{},'.format(int(x[0]), int(x[1]), int(x[2] + x[0]), int(x[3] + x[1]))) + df_annotations[
                                      'index'].astype('str')
        df_annotations['image_path'] = df_annotations['image_id'].apply(
            lambda x: data_root + '/images/{}.jpg'.format(x))

        df_annotations['image_path'] = df_annotations['image_id'].apply(
            lambda x: data_root + '/images/{}{}.jpg'.format('0' * (12 - len(str(x))), x))

        df_res = pd.DataFrame(
            df_annotations[['image_path', 'label']].groupby(['image_path'])['label'].apply(list).apply(
                lambda x: ' '.join(x))).reset_index()

        df_res.to_csv(target_file, header=None, index=None, sep=' ', quotechar=' ', )

    # step1()
    data_root = path_parse(data_root)
    step2(json_path=data_root + '/annotations/instances_train2017.json', target_file=data_root + 'train2017.txt')
    step2(json_path=data_root + '/annotations/instances_val2017.json', target_file=data_root + 'val2017.txt')



from .core import ElectronicsData
from .core import get_adult_data
from .core import get_bitly_usagov_data
from .core import get_electronics
from .core import get_movielens
from .core import get_movielens
from .core import get_porto_seguro_data



import pandas as pd
from notedata.dataset.datas import ElectronicsData
from notedata.manage import DatasetManage
from notetool.tool import log

logger = log(__name__)


def get_electronics(dataset: DatasetManage = None):
    electronic = ElectronicsData(dataset=dataset, data_path='./download/')
    electronic.init_data()


def get_movielens(dataset: DatasetManage = None):
    dataset.download('movielens-100k', overwrite=False)
    dataset.download('movielens-1m', overwrite=False)
    dataset.download('movielens-10m', overwrite=False)
    dataset.download('movielens-20m', overwrite=False)
    dataset.download('movielens-25m', overwrite=False)
    # os.system('cd ' + file_path(data.path) + ' && unzip ' + file_name(data.path))


def get_adult_data(dataset: DatasetManage = None):
    data_train = dataset.download('adult-train', overwrite=False)
    data_test = dataset.download('adult-test', overwrite=False)

    print(data_test)
    train_data = pd.read_table(data_train.path, header=None, delimiter=',')
    test_data = pd.read_table(
        data_test.path, header=None, delimiter=',', error_bad_lines=False)

    # all_columns = ['age', 'workclass', 'fnlwgt', 'education', 'education-num', 'marital-status', 'occupation',
    #                'relationship', 'race', 'sex', 'capital-gain', 'capital-loss', 'hours-per-week', 'native-country',
    #                'label', 'type']
    #
    # continus_columns = ['age', 'fnlwgt', 'education-num', 'capital-gain', 'capital-loss', 'hours-per-week']
    # dummy_columns = ['workclass', 'education', 'marital-status', 'occupation', 'relationship', 'race', 'sex',
    #                  'native-country']
    #
    # train_data['type'] = 1
    # test_data['type'] = 2
    #
    # all_data = pd.concat([train_data, test_data], axis=0)
    # all_data.columns = all_columns
    #
    # all_data = pd.get_dummies(all_data, columns=dummy_columns)
    #
    # test_data = all_data[all_data['type'] == 2].drop(['type'], axis=1)
    # train_data = all_data[all_data['type'] == 1].drop(['type'], axis=1)
    #
    # train_data['label'] = train_data['label'].map(lambda x: 1 if x.strip() == '>50K' else 0)
    # test_data['label'] = test_data['label'].map(lambda x: 1 if str(x).strip() == '>50K.' else 0)
    #
    # for col in continus_columns:
    #     ss = StandardScaler()
    #     train_data[col] = ss.fit_transform(train_data[[col]].astype(np.float64))
    #     test_data[col] = ss.transform(test_data[[col]].astype(np.float64))
    #
    # train_y = train_data['label']
    # train_x = train_data.drop(['label'], axis=1)
    # test_y = test_data['label']
    # test_x = test_data.drop(['label'], axis=1)
    #
    # return train_x, train_y, test_x, test_y


def get_porto_seguro_data(dataset: DatasetManage = None):
    dataset.download('porto-seguro-train')
    dataset.download('porto-seguro-test')


def get_bitly_usagov_data(dataset: DatasetManage = None):
    dataset.download('bitly-usagov')
